@@ -47,8 +47,8 @@ class CollapsableButton : public QWidget
     void toggled();
 
   protected:
-    virtual void paintEvent(QPaintEvent *ev);
-    virtual void mouseReleaseEvent(QMouseEvent *ev);
+    void paintEvent(QPaintEvent *ev) Q_DECL_OVERRIDE;
+    void mouseReleaseEvent(QMouseEvent *ev) Q_DECL_OVERRIDE;
 
   private:
     bool mCollapsed;
